Supported Platforms
===================

We're now supporting Linux systems which have at least python 2.7 for
builders and 3.6 for other components. These versions are minimal (so,
everywhere where is 2.7 support it means 2.7+ *and* 3.0+. Currently it
involves all active Fedoras and RHEL/CentOS 7+.

+-----------+-----+-----+---------+-------+-----+-----+
| Component | Hub | Web | Builder | Utils | Lib | CLI |
+===========+=====+=====+=========+=======+=====+=====+
| Python    | 3.6 | 3.6 | 2.7     | 3.6   | 2.7 | 2.7 |
+-----------+-----+-----+---------+-------+-----+-----+
